==> cryptol-3.3.0-23-riscv64.pkg.tar.zst: usr/share/haskell/register/cryptol.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cryptol
version:              3.3.0
visibility:           public
id:                   cryptol-3.3.0-Jvdd0a31VgrYvvHZvWZop
key:                  cryptol-3.3.0-Jvdd0a31VgrYvvHZvWZop
license:              BSD-3-Clause
copyright:            2013-2025 Galois Inc.
maintainer:           cryptol@galois.com
author:               Galois, Inc.
homepage:             https://tools.galois.com/cryptol
synopsis:             Cryptol: The Language of Cryptography
description:
    Cryptol is a domain-specific language for specifying cryptographic algorithms. A Cryptol implementation of an algorithm resembles its mathematical specification more closely than an implementation in a general purpose language. For more, see <http://www.cryptol.net/>.

category:             Language
abi:                  10987e0f6b1f1fa8491a2404d2953f3e
exposed:              True
exposed-modules:
    Cryptol.AES Cryptol.Backend Cryptol.Backend.Arch
    Cryptol.Backend.Concrete Cryptol.Backend.FFI
    Cryptol.Backend.FFI.Error Cryptol.Backend.FloatHelpers
    Cryptol.Backend.Monad Cryptol.Backend.SBV Cryptol.Backend.SeqMap
    Cryptol.Backend.What4 Cryptol.Backend.WordValue Cryptol.Eval
    Cryptol.Eval.Concrete Cryptol.Eval.Env Cryptol.Eval.FFI
    Cryptol.Eval.FFI.GenHeader Cryptol.Eval.Generic Cryptol.Eval.Prims
    Cryptol.Eval.Reference Cryptol.Eval.SBV Cryptol.Eval.Type
    Cryptol.Eval.Value Cryptol.Eval.What4 Cryptol.F2
    Cryptol.IR.FreeVars Cryptol.IR.TraverseNames Cryptol.ModuleSystem
    Cryptol.ModuleSystem.Base Cryptol.ModuleSystem.Binds
    Cryptol.ModuleSystem.Env Cryptol.ModuleSystem.Exports
    Cryptol.ModuleSystem.Fingerprint Cryptol.ModuleSystem.Interface
    Cryptol.ModuleSystem.Monad Cryptol.ModuleSystem.Name
    Cryptol.ModuleSystem.Names Cryptol.ModuleSystem.NamingEnv
    Cryptol.ModuleSystem.NamingEnv.Types Cryptol.ModuleSystem.Renamer
    Cryptol.ModuleSystem.Renamer.Error
    Cryptol.ModuleSystem.Renamer.ImplicitImports
    Cryptol.ModuleSystem.Renamer.Imports
    Cryptol.ModuleSystem.Renamer.Monad Cryptol.Parser
    Cryptol.Parser.AST Cryptol.Parser.ExpandPropGuards
    Cryptol.Parser.Layout Cryptol.Parser.Lexer Cryptol.Parser.Name
    Cryptol.Parser.Names Cryptol.Parser.NoInclude Cryptol.Parser.NoPat
    Cryptol.Parser.Position Cryptol.Parser.Selector
    Cryptol.Parser.Token Cryptol.Parser.Unlit Cryptol.Parser.Utils
    Cryptol.PrimeEC Cryptol.Project Cryptol.Project.Cache
    Cryptol.Project.Config Cryptol.Project.Monad
    Cryptol.Project.WildMatch Cryptol.REPL.Browse Cryptol.REPL.Command
    Cryptol.REPL.Help Cryptol.REPL.Monad Cryptol.REPL.Trie Cryptol.SHA
    Cryptol.Symbolic Cryptol.Symbolic.SBV Cryptol.Symbolic.What4
    Cryptol.Testing.Random Cryptol.Transform.MonoValues
    Cryptol.Transform.Specialize Cryptol.TypeCheck
    Cryptol.TypeCheck.AST Cryptol.TypeCheck.Default
    Cryptol.TypeCheck.Error Cryptol.TypeCheck.FFI
    Cryptol.TypeCheck.FFI.Error Cryptol.TypeCheck.FFI.FFIType
    Cryptol.TypeCheck.Infer Cryptol.TypeCheck.InferTypes
    Cryptol.TypeCheck.Instantiate Cryptol.TypeCheck.Interface
    Cryptol.TypeCheck.Kind Cryptol.TypeCheck.Module
    Cryptol.TypeCheck.ModuleBacktickInstance
    Cryptol.TypeCheck.ModuleInstance Cryptol.TypeCheck.Monad
    Cryptol.TypeCheck.PP Cryptol.TypeCheck.Parseable
    Cryptol.TypeCheck.Sanity Cryptol.TypeCheck.SimpType
    Cryptol.TypeCheck.SimpleSolver Cryptol.TypeCheck.Solve
    Cryptol.TypeCheck.Solver.Class Cryptol.TypeCheck.Solver.Improve
    Cryptol.TypeCheck.Solver.InfNat Cryptol.TypeCheck.Solver.Numeric
    Cryptol.TypeCheck.Solver.Numeric.Fin
    Cryptol.TypeCheck.Solver.Numeric.Interval
    Cryptol.TypeCheck.Solver.SMT Cryptol.TypeCheck.Solver.Selector
    Cryptol.TypeCheck.Solver.Types Cryptol.TypeCheck.Solver.Utils
    Cryptol.TypeCheck.Subst Cryptol.TypeCheck.TCon
    Cryptol.TypeCheck.Type Cryptol.TypeCheck.TypeMap
    Cryptol.TypeCheck.TypeOf Cryptol.TypeCheck.TypePat
    Cryptol.TypeCheck.Unify Cryptol.Utils.Benchmark Cryptol.Utils.Debug
    Cryptol.Utils.Fixity Cryptol.Utils.Ident Cryptol.Utils.Logger
    Cryptol.Utils.Misc Cryptol.Utils.PP Cryptol.Utils.Panic
    Cryptol.Utils.Patterns Cryptol.Utils.RecordMap Cryptol.Utils.Types
    Cryptol.Version

hidden-modules:
    Cryptol.Parser.LexerUtils Cryptol.Parser.ParserUtils
    Cryptol.Prelude GHC.Num.Compat Paths_cryptol GitRev

import-dirs:          /usr/lib/ghc-9.4.8/site-local/cryptol-3.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cryptol-3.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cryptol-3.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/cryptol
hs-libraries:         HScryptol-3.3.0-Jvdd0a31VgrYvvHZvWZop
depends:
    GraphSCC-1.0.4-BvH3gdGqztj6roihacPJAg
    MemoTrie-0.6.11-2FivWXzu1Qe4XIyz5xz0Nj
    arithmoi-0.13.2.0-LJzYUup0GgzDqzZRjJ4a2o array-0.5.4.0
    async-2.2.5-GGvJE1nOBFYGFw0FXsPFU0 base-4.17.2.1
    base-compat-0.14.1-EDnSvJBeGTDBBfh2KFPKKz
    bv-sized-1.0.6-5oEul6zt1G3JA0wtjT5LK bytestring-0.11.5.3
    containers-0.6.7
    criterion-measurement-0.2.3.0-AuW4rfWuOn97oYymrxMoo4
    cryptohash-sha256-0.11.102.1-9lKR7BNsiyq7t2yDe4jjeV deepseq-1.4.8.0
    directory-1.3.7.1 exceptions-0.10.5
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY filepath-1.4.2.2
    ghc-bignum-1.3 ghc-prim-0.9.1 gitrev-1.3.1-EAQEu0I0MYZ3NOvBCjPIAO
    heredoc-0.2.0.0-77nW0mrU6iW6fQsJ6nWzcx
    hgmp-0.1.2.1-8ZJM6hbsLoG4bcBJlaiGJM
    language-c99-0.2.0-I2YO1ITQKgi7h1b2QKXgRh
    language-c99-simple-0.3.0-LtsnH0LVnu56Mhd4fxlDo
    libBF-0.6.6-EikARrx3HOzI3GJqje3fxy
    libffi-0.2.1-DPsLfzr2gvt1V2FBULxP58
    monad-control-1.0.3.1-5KQQUvViYP35kwtWEUOPGs
    monadLib-3.10.3-9u69WCWPr5d93B1By2kxXa mtl-2.2.2
    panic-0.4.0.1-3QvhbYIlGoL4pBeY3qhGHr
    parameterized-utils-2.1.10.0-GzuSb1xDXv4DyqINT4dPm9 pretty-1.1.3.6
    pretty-show-1.10-Ey6CADemQl3EFi7OIHqHDp
    prettyprinter-1.7.1-IxfK3MMc5TsGC7SkX421m7 process-1.6.18.0
    sbv-10.2-ELpfgDhtnBWDa2cIavlC4B
    simple-smt-0.9.8-GxJMYuz27wdJmfDJ6DG7cL stm-2.5.1.0
    strict-0.5.1-DOtb9Mi0AldCt12sYxVGp0 text-2.0.2
    tf-random-0.5-5of6DWppTHeFaBLq7uTU4g time-1.12.2
    toml-parser-2.0.1.2-Jyfcp2P0Ktr2a8HkF1pfad
    transformers-base-0.4.6-72fNkPW8m0RFmUAZLkd9QA unix-2.7.3
    vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS
    what4-1.6-IUEuV5oA2SCEkZcKfVLpq4

haddock-interfaces:   /usr/share/doc/cryptol/html/cryptol.haddock
haddock-html:         /usr/share/doc/cryptol/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-cryptol-z-cryptol-repl-internal
version:              3.3.0
package-name:         cryptol
lib-name:             cryptol-repl-internal
id:                   cryptol-3.3.0-B6nL9RmYmZZADisxRwOfuq-cryptol-repl-internal
key:                  cryptol-3.3.0-B6nL9RmYmZZADisxRwOfuq-cryptol-repl-internal
license:              BSD-3-Clause
copyright:            2013-2025 Galois Inc.
maintainer:           cryptol@galois.com
author:               Galois, Inc.
homepage:             https://tools.galois.com/cryptol
synopsis:             Cryptol: The Language of Cryptography
description:
    Cryptol is a domain-specific language for specifying cryptographic algorithms. A Cryptol implementation of an algorithm resembles its mathematical specification more closely than an implementation in a general purpose language. For more, see <http://www.cryptol.net/>.

category:             Language
abi:                  93af87af11f40f6ea581b92a7e4e8c21
exposed-modules:      REPL.Haskeline REPL.Logo
hidden-modules:       Paths_cryptol
import-dirs:          /usr/lib/ghc-9.4.8/site-local/cryptol-3.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cryptol-3.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cryptol-3.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/cryptol
hs-libraries:
    HScryptol-3.3.0-B6nL9RmYmZZADisxRwOfuq-cryptol-repl-internal

depends:
    ansi-terminal-1.0.2-HSq0v3QUl8T11Wgx1QLnTe base-4.17.2.1
    base-compat-0.14.1-EDnSvJBeGTDBBfh2KFPKKz containers-0.6.7
    cryptol-3.3.0-Jvdd0a31VgrYvvHZvWZop directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2 haskeline-0.8.2
    monad-control-1.0.3.1-5KQQUvViYP35kwtWEUOPGs text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/cryptol/html/cryptol.haddock
haddock-html:         /usr/share/doc/cryptol/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> cryptol-3.3.0-38-riscv64.pkg.tar.zst: usr/share/haskell/register/cryptol.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cryptol
version:              3.3.0
visibility:           public
id:                   cryptol-3.3.0-AQ1RxXc3vPlFQJfWPTHkbI
key:                  cryptol-3.3.0-AQ1RxXc3vPlFQJfWPTHkbI
license:              BSD-3-Clause
copyright:            2013-2025 Galois Inc.
maintainer:           cryptol@galois.com
author:               Galois, Inc.
homepage:             https://tools.galois.com/cryptol
synopsis:             Cryptol: The Language of Cryptography
description:
    Cryptol is a domain-specific language for specifying cryptographic algorithms. A Cryptol implementation of an algorithm resembles its mathematical specification more closely than an implementation in a general purpose language. For more, see <http://www.cryptol.net/>.

category:             Language
abi:                  3cb55ada1cd8a8bab996b71868fa2f28
exposed:              True
exposed-modules:
    Cryptol.AES Cryptol.Backend Cryptol.Backend.Arch
    Cryptol.Backend.Concrete Cryptol.Backend.FFI
    Cryptol.Backend.FFI.Error Cryptol.Backend.FloatHelpers
    Cryptol.Backend.Monad Cryptol.Backend.SBV Cryptol.Backend.SeqMap
    Cryptol.Backend.What4 Cryptol.Backend.WordValue Cryptol.Eval
    Cryptol.Eval.Concrete Cryptol.Eval.Env Cryptol.Eval.FFI
    Cryptol.Eval.FFI.GenHeader Cryptol.Eval.Generic Cryptol.Eval.Prims
    Cryptol.Eval.Reference Cryptol.Eval.SBV Cryptol.Eval.Type
    Cryptol.Eval.Value Cryptol.Eval.What4 Cryptol.F2
    Cryptol.IR.FreeVars Cryptol.IR.TraverseNames Cryptol.ModuleSystem
    Cryptol.ModuleSystem.Base Cryptol.ModuleSystem.Binds
    Cryptol.ModuleSystem.Env Cryptol.ModuleSystem.Exports
    Cryptol.ModuleSystem.Fingerprint Cryptol.ModuleSystem.Interface
    Cryptol.ModuleSystem.Monad Cryptol.ModuleSystem.Name
    Cryptol.ModuleSystem.Names Cryptol.ModuleSystem.NamingEnv
    Cryptol.ModuleSystem.NamingEnv.Types Cryptol.ModuleSystem.Renamer
    Cryptol.ModuleSystem.Renamer.Error
    Cryptol.ModuleSystem.Renamer.ImplicitImports
    Cryptol.ModuleSystem.Renamer.Imports
    Cryptol.ModuleSystem.Renamer.Monad Cryptol.Parser
    Cryptol.Parser.AST Cryptol.Parser.ExpandPropGuards
    Cryptol.Parser.Layout Cryptol.Parser.Lexer Cryptol.Parser.Name
    Cryptol.Parser.Names Cryptol.Parser.NoInclude Cryptol.Parser.NoPat
    Cryptol.Parser.Position Cryptol.Parser.Selector
    Cryptol.Parser.Token Cryptol.Parser.Unlit Cryptol.Parser.Utils
    Cryptol.PrimeEC Cryptol.Project Cryptol.Project.Cache
    Cryptol.Project.Config Cryptol.Project.Monad
    Cryptol.Project.WildMatch Cryptol.REPL.Browse Cryptol.REPL.Command
    Cryptol.REPL.Help Cryptol.REPL.Monad Cryptol.REPL.Trie Cryptol.SHA
    Cryptol.Symbolic Cryptol.Symbolic.SBV Cryptol.Symbolic.What4
    Cryptol.Testing.Random Cryptol.Transform.MonoValues
    Cryptol.Transform.Specialize Cryptol.TypeCheck
    Cryptol.TypeCheck.AST Cryptol.TypeCheck.Default
    Cryptol.TypeCheck.Error Cryptol.TypeCheck.FFI
    Cryptol.TypeCheck.FFI.Error Cryptol.TypeCheck.FFI.FFIType
    Cryptol.TypeCheck.Infer Cryptol.TypeCheck.InferTypes
    Cryptol.TypeCheck.Instantiate Cryptol.TypeCheck.Interface
    Cryptol.TypeCheck.Kind Cryptol.TypeCheck.Module
    Cryptol.TypeCheck.ModuleBacktickInstance
    Cryptol.TypeCheck.ModuleInstance Cryptol.TypeCheck.Monad
    Cryptol.TypeCheck.PP Cryptol.TypeCheck.Parseable
    Cryptol.TypeCheck.Sanity Cryptol.TypeCheck.SimpType
    Cryptol.TypeCheck.SimpleSolver Cryptol.TypeCheck.Solve
    Cryptol.TypeCheck.Solver.Class Cryptol.TypeCheck.Solver.Improve
    Cryptol.TypeCheck.Solver.InfNat Cryptol.TypeCheck.Solver.Numeric
    Cryptol.TypeCheck.Solver.Numeric.Fin
    Cryptol.TypeCheck.Solver.Numeric.Interval
    Cryptol.TypeCheck.Solver.SMT Cryptol.TypeCheck.Solver.Selector
    Cryptol.TypeCheck.Solver.Types Cryptol.TypeCheck.Solver.Utils
    Cryptol.TypeCheck.Subst Cryptol.TypeCheck.TCon
    Cryptol.TypeCheck.Type Cryptol.TypeCheck.TypeMap
    Cryptol.TypeCheck.TypeOf Cryptol.TypeCheck.TypePat
    Cryptol.TypeCheck.Unify Cryptol.Utils.Benchmark Cryptol.Utils.Debug
    Cryptol.Utils.Fixity Cryptol.Utils.Ident Cryptol.Utils.Logger
    Cryptol.Utils.Misc Cryptol.Utils.PP Cryptol.Utils.Panic
    Cryptol.Utils.Patterns Cryptol.Utils.RecordMap Cryptol.Utils.Types
    Cryptol.Version

hidden-modules:
    Cryptol.Parser.LexerUtils Cryptol.Parser.ParserUtils
    Cryptol.Prelude GHC.Num.Compat Paths_cryptol GitRev

import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/cryptol-3.3.0
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/cryptol-3.3.0
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/cryptol-3.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/cryptol
hs-libraries:         HScryptol-3.3.0-AQ1RxXc3vPlFQJfWPTHkbI
depends:
    GraphSCC-1.0.4-2MSKzq0PjtF4hFrC9rq2lD
    MemoTrie-0.6.11-HKYG1gjsvdoKLKhOXA0cAl
    arithmoi-0.13.2.0-1VGZfZ17S9lAkfluo8qbkp array-0.5.8.0
    async-2.2.5-1ovq96REeQVKYsP5cduurl base-4.18.3.0
    base-compat-0.14.1-FK5GrXzRHJlIaqVbFVqjup
    bv-sized-1.0.6-H4VEuGaOApT60VUypd6NZq bytestring-0.11.5.4
    containers-0.6.7
    criterion-measurement-0.2.3.0-EGgkvknKAF8FoKAq4dSyoE
    cryptohash-sha256-0.11.102.1-6oFe6jjLSblHef4XZuGQge deepseq-1.4.8.1
    directory-1.3.8.5 exceptions-0.10.7
    file-embed-0.0.16.0-Heqv1MGULDp1AU5LH7qKhb filepath-1.4.301.0
    ghc-bignum-1.3 ghc-prim-0.10.0 gitrev-1.3.1-EZaugGGDFs6BV1nDP6kF4G
    heredoc-0.2.0.0-HMXo4KdxhxAI85xN89g22p
    hgmp-0.1.2.1-K0lHl1VuOGxGKmoxsdPIuI
    language-c99-0.2.0-2qX1bYxPmiSCWHJtbCZ3ay
    language-c99-simple-0.3.0-X4XLH3vDXeJTB6Gp7ZVZS
    libBF-0.6.7-7VRZIIOTJsTHYuHbkI0wbk
    libffi-0.2.1-I31kPfh3SzFAH6Y97HCmaD
    monad-control-1.0.3.1-FK5MwN7CLMeDFbgWPeqycv
    monadLib-3.10.3-9ph6EPXOQLOCoIBrLmOhZ1 mtl-2.3.1
    panic-0.4.0.1-d2Jh8dqfFgDrmaGeX7wx2
    parameterized-utils-2.1.11.0-2epFv6Cg4AoJ5EajwJh5t0 pretty-1.1.3.6
    pretty-show-1.10-IMyOnqPwisgFJLGoHg4EWf
    prettyprinter-1.7.1-LHlHufkI3KGGUhqO6HPUXq process-1.6.19.0
    sbv-10.3-LKSq91Zc3Fd5cwgjyTKi5n
    simple-smt-0.9.8-HorZOu0r1ZP5NOXQsNePlT stm-2.5.1.0
    strict-0.5.1-2qreVmQS6xqA7wSvTCBI0d text-2.0.2
    tf-random-0.5-L2JSp8dBhDD9u6nqt3iNmO time-1.12.2
    toml-parser-2.0.1.2-4xKanQciNep6gXcsJwaDYp
    transformers-base-0.4.6-KecQozQ2bJs3HLDcaEYSEy unix-2.8.6.0
    vector-0.13.2.0-BINMV7y6ibUKgFTnLXEi1A
    what4-1.6-1HOFq3cPhJz8NtWPSsPOn4

haddock-interfaces:   /usr/share/doc/cryptol/html/cryptol.haddock
haddock-html:         /usr/share/doc/cryptol/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-cryptol-z-cryptol-repl-internal
version:              3.3.0
package-name:         cryptol
lib-name:             cryptol-repl-internal
id:                   cryptol-3.3.0-3PGShHQZer05v9ErYckLAO-cryptol-repl-internal
key:                  cryptol-3.3.0-3PGShHQZer05v9ErYckLAO-cryptol-repl-internal
license:              BSD-3-Clause
copyright:            2013-2025 Galois Inc.
maintainer:           cryptol@galois.com
author:               Galois, Inc.
homepage:             https://tools.galois.com/cryptol
synopsis:             Cryptol: The Language of Cryptography
description:
    Cryptol is a domain-specific language for specifying cryptographic algorithms. A Cryptol implementation of an algorithm resembles its mathematical specification more closely than an implementation in a general purpose language. For more, see <http://www.cryptol.net/>.

category:             Language
abi:                  e01c9055f15fcd07f92393b76a0e528f
exposed-modules:      REPL.Haskeline REPL.Logo
hidden-modules:       Paths_cryptol
import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/cryptol-3.3.0
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/cryptol-3.3.0
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/cryptol-3.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/cryptol
hs-libraries:
    HScryptol-3.3.0-3PGShHQZer05v9ErYckLAO-cryptol-repl-internal

depends:
    ansi-terminal-1.1-4EeIQsn6Wrq78PCXTndXTh base-4.18.3.0
    base-compat-0.14.1-FK5GrXzRHJlIaqVbFVqjup containers-0.6.7
    cryptol-3.3.0-AQ1RxXc3vPlFQJfWPTHkbI directory-1.3.8.5
    exceptions-0.10.7 filepath-1.4.301.0 haskeline-0.8.2.1
    monad-control-1.0.3.1-FK5MwN7CLMeDFbgWPeqycv text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/cryptol/html/cryptol.haddock
haddock-html:         /usr/share/doc/cryptol/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
